/**
        \file commands.h
        \author Sachith Dunatunga
        \date 17.05.09
        \version 1.0

        The header for all the commands that can be called from the
        p2kc-linux command line interface.
*/
#ifndef __COMMANDS_H__
#define __COMMANDS_H__
/* ---args----------------------------------------------------------------- */
/**
        \brief A typedef to functions that take arguments in the same way as
        the main function.
*/
typedef int (main_func_t)(int, char **);

/**
        \brief A structure to hold commands.

        This structure holds not only arguments, but also function pointers
        and the command name.
*/
struct command_s {
        /**
                \brief The name of this command.
        */
        char *name;
        /**
                \brief A pointer to the function that this structure encloses.
        */
        main_func_t *func;
        /**
                \brief The number of arguments.
        */
        int argc;
        /**
                \brief The array of arguments.

                All of the arguments in the array are null terminated,
                although the argument list itself is not null terminated.
        */
        char **argv;
};

/**
        \brief A typedef to improve clarity.
*/
typedef struct command_s command_t;
/* ------------------------------------------------------------------------ */
#endif
