/**
        \file scanner.h
        \author Sachith Dunatunga
        \date 21.04.09
        \brief The header/interface for libparagon bus scanning functions.
*/
#ifndef __PARAGON_SCANNER_H__
#define __PARAGON_SCANNER_H__
#include "paragon.h"

/* ---libparagon----------------------------------------------------------- */
/**
        \brief This function scans all busses and devices for Motorola
        interfaces.
        \param handle The libparagon handle to use.
        \param vid The vendor ID of devices to scan.
        \param pid The product ID of devices to scan.
        \param mode The mode to scan for.
        \return PARAGON_SUCCESS on success, an integer less than 0 on error.

        This function will try to find the interface corresponding to the
        requested mode; if mode is PARAGON_MODE_AUTO or PARAGON_MORE_UNKNOWN
        it will scan for for interfaces from all different modes. If it finds
        an interface, it will set the handle->mode to the correct mode. You
        can use PARAGON_ANY_VENDOR and PARAGON_ANY_PRODUCT if you do not
        wish to filter according to Vendor ID or Product ID respectively.
*/
int paragon_scan(paragon_handle_t *handle, int vid, int pid, int mode);
/* ------------------------------------------------------------------------ */
#endif
